![Transport for the North Logo](https://github.com/Transport-for-the-North/caf.toolkit/blob/main/docs/TFN_Landscape_Colour_CMYK.png)

<h1 align="center">CAF Distribute</h1>

<p align="center">
<a href="https://pypi.org/project/caf.distribute/"><img alt="Supported Python versions" src="https://img.shields.io/pypi/pyversions/caf.distribute.svg?style=flat-square"></a>
<a href="https://pypi.org/project/caf.distribute/"><img alt="Latest release" src="https://img.shields.io/github/release/transport-for-the-north/caf.distribute.svg?style=flat-square&maxAge=86400"></a>
<a href="https://anaconda.org/conda-forge/caf.distribute"><img alt="Conda" src="https://img.shields.io/conda/v/conda-forge/caf.distribute?style=flat-square&logo=condaforge"></a>
<a href="https://app.codecov.io/gh/Transport-for-the-North/caf.distribute"><img alt="Coverage" src="https://img.shields.io/codecov/c/github/transport-for-the-north/caf.distribute.svg?branch=master&style=flat-square&logo=CodeCov"></a>
<a href="https://github.com/Transport-for-the-North/caf.distribute/actions?query=event%3Apush"><img alt="Testing Badge" src="https://img.shields.io/github/actions/workflow/status/transport-for-the-north/caf.toolkit/tests.yml?style=flat-square&logo=GitHub&label=Tests"></a>
<a href='https://cafdistribute.readthedocs.io/en/stable/?badge=stable'><img alt='Documentation Status' src="https://img.shields.io/readthedocs/cafdistribute?style=flat-square&logo=readthedocs"></a>
<a href="https://github.com/psf/black"><img alt="code style: black" src="https://img.shields.io/badge/code%20format-black-000000.svg?style=flat-square"></a>
</p>

A module of CAF for distributing demand across matrices.

The Common Analytical Framework (CAF) is a toolkit of transport planning and appraisal 
functionalities.
It's part of a project to make a lot of the useful transport related functionality 
more widely available and easily accessible.
Other modules include:
- [CAF.Toolkit](https://github.com/Transport-for-the-North/caf.toolkit)
- [CAF.Space](https://github.com/Transport-for-the-North/caf.space)
- [CAF.Viz](https://github.com/Transport-for-the-North/caf.viz)


### Contributing
CAF.Distribute happily accepts contributions.

The best way to contribute to this project is to go to the issues tab and report 
bugs or submit a feature request. This helps CAF.Distribute become more stable 
and full-featured. Please check the closed bugs before submitting a bug report 
to see if your question has already been answered.
